==> gibasa_0.9.5.tar.gz: gibasa/tests/testthat/_snaps/pack.md <==
# packing into ngrams works

    {
      "type": "list",
      "attributes": {
        "class": {
          "type": "character",
          "attributes": {},
          "value": ["tbl_df", "tbl", "data.frame"]
        },
        "row.names": {
          "type": "integer",
          "attributes": {},
          "value": [1, 2, 3, 4]
        },
        "names": {
          "type": "character",
          "attributes": {},
          "value": ["doc_id", "text"]
        }
      },
      "value": [
        {
          "type": "integer",
          "attributes": {
            "levels": {
              "type": "character",
              "attributes": {},
              "value": ["1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", "31", "32", "33", "34", "35", "36", "37", "38", "39", "40", "41", "42", "43", "44", "45", "46", "47", "48", "49", "50"]
            },
            "class": {
              "type": "character",
              "attributes": {},
              "value": ["factor"]
            }
          },
          "value": [1, 2, 3, 4]
        },
        {
          "type": "character",
          "attributes": {},
          "value": ["銀河 鉄道 の 夜", "宮沢 賢治", "一 　 午後 の 授業", "「 では みなさん は 、 そういう ふう に 川 だ と 言わ れ たり 、 乳 の 流れ た あと だ と 言わ れ たり し て い た 、 この ぼんやり と 白い もの が ほんとう は 何 か ご 承知 です か 」 先生 は 、 黒板 に つるし た 大きな 黒い 星座 の 図 の 、 上 から 下 へ 白く けぶっ た 銀河 帯 の よう な ところ を 指し ながら 、 みんな に 問い を かけ まし た 。"]
        }
      ]
    }

==> gibasa_1.1.1.tar.gz: gibasa/tests/testthat/_snaps/pack.md <==
# packing into ngrams works

    {
      "type": "list",
      "attributes": {
        "class": {
          "type": "character",
          "attributes": {},
          "value": ["tbl_df", "tbl", "data.frame"]
        },
        "row.names": {
          "type": "integer",
          "attributes": {},
          "value": [1, 2, 3, 4]
        },
        "names": {
          "type": "character",
          "attributes": {},
          "value": ["doc_id", "text"]
        }
      },
      "value": [
        {
          "type": "integer",
          "attributes": {
            "levels": {
              "type": "character",
              "attributes": {},
              "value": ["1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", "31", "32", "33", "34", "35", "36", "37", "38", "39", "40", "41", "42", "43", "44", "45", "46", "47", "48", "49", "50"]
            },
            "class": {
              "type": "character",
              "attributes": {},
              "value": ["factor"]
            }
          },
          "value": [1, 2, 3, 4]
        },
        {
          "type": "character",
          "attributes": {},
          "value": ["銀河-鉄道 鉄道-の の-夜", "宮沢-賢治", "一-　 　-午後 午後-の の-授業", "「-では では-みなさん みなさん-は は-、 、-そういう そういう-ふう ふう-に に-川 川-だ だ-と と-言わ 言わ-れ れ-たり たり-、 、-乳 乳-の の-流れ 流れ-た た-あと あと-だ だ-と と-言わ 言わ-れ れ-たり たり-し し-て て-い い-た た-、 、-この この-ぼんやり ぼんやり-と と-白い 白い-もの もの-が が-ほんとう ほんとう-は は-何 何-か か-ご ご-承知 承知-です です-か か-」 」-先生 先生-は は-、 、-黒板 黒板-に に-つるし つるし-た た-大きな 大きな-黒い 黒い-星座 星座-の の-図 図-の の-、 、-上 上-から から-下 下-へ へ-白く 白く-けぶっ けぶっ-た た-銀河 銀河-帯 帯-の の-よう よう-な な-ところ ところ-を を-指し 指し-ながら ながら-、 、-みんな みんな-に に-問い 問い-を を-かけ かけ-まし まし-た た-。"]
        }
      ]
    }
